@@ -82,7 +82,7 @@ impl ReadoutKey {
                 values.insert(&AbbreviationType::Alternative, "Cpu");
                 values.insert(&AbbreviationType::Long, "Processor");
             }
-            ReadoutKey::ProcessorUsage => {
+            ReadoutKey::ProcessorLoad => {
                 values.insert(&AbbreviationType::Classic, "CPU%");
                 values.insert(&AbbreviationType::Alternative, "Cp%");
                 values.insert(&AbbreviationType::Long, "Processor Usage");
